=tooltip-fade
	&::before,
	&::after
		transition: opacity $tooltip-animation-duration $tooltip-animation-transition-timing-function, visibility $tooltip-animation-duration $tooltip-animation-transition-timing-function