const defaultOptions = {
    'selector': '.step-item',
    'selector_content': '.step-content',
    'previous_selector': '[data-nav="previous"]',
    'next_selector': '[data-nav="next"]',
    'active_class': 'is-active',
    'completed_class': 'is-completed',
    'stepClickable': false,
    'beforeNext': null,
    'onShow': null,
    'onFinish': null,
    'onError': null
};

export default defaultOptions;
